<?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassX</source>
        <translation>Om KeePassX</translation>
    </message>
    <message>
        <source>KeePassX is distributed under the term of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation>KeePassX distribueres under betingelserne i GNU General Public License (GPL) version 2 eller (efter eget valg) version 3.</translation>
    </message>
    <message>
        <source>Revision</source>
        <translation>Revision</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Bruger:</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>Auto-indsæt - KeePassX</translation>
    </message>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation>Kunne ikke finde en post, der matcher vinduets titel:</translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation>Vindue</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation>Sekvens</translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation>Standardsekvens</translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>Auto-indsæt - KeePassX</translation>
    </message>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation>Vælg post til Auto-Indsæt:</translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation>Kodeord</translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation>Indtast kodeord</translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation>Gentag kodeord</translation>
    </message>
    <message>
        <source>Key file</source>
        <translation>Nøglefil</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Gennemse</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Opret</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Nøglefiler</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle filer</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>Opret Nøglefil...</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation>Kan ikke oprette Nøglefil :</translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation>Vælg en nøglefil</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Spørgsmål</translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation>Vil du virkelig bruge en tom streng som kodeord?</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Andre kodeord leveret.</translation>
    </message>
    <message>
        <source>Failed to set key file</source>
        <translation>Kan ikke sætte nøglefil</translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation>Kunne ikke sætte %1 som Nøglefil:
%2</translation>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation>Indtast hovednøgle</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>Nøglefil:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Kodeord:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Gennemse</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Kan ikke åbne databasen.</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Kan ikke åbne nøglefil</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle filer</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Nøglefiler</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>Vælg nøglefil</translation>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation>Reparer database</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Kan ikke åbne nøglefil</translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation>Databasen åbnede fint. Intet at gøre.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Kan ikke åbne databasen.</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation>Databasen er blevet succesfuldt repareret
Du kan gemme den nu.</translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation>Kan ikke reparere databasen.</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation>Databasenavn:</translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation>Beskrivelse af database:</translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation>Transformationsrunder:</translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation>Standard brugernavn:</translation>
    </message>
    <message>
        <source>Use recycle bin:</source>
        <translation>Brug skraldespand:</translation>
    </message>
    <message>
        <source> MiB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation>Benchmark</translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation>Maks. posthistorik:</translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation>Maks. historikstørrelse:</translation>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation>Rod</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 Database</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle filer</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Åben database</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation>Filen blev ikke fundet!</translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation>Åben KeePass 1 database</translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation>KeePass 1 database</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Alle filer (*)</translation>
    </message>
    <message>
        <source>Close?</source>
        <translation>Luk?</translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation>Gem ændringer?</translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation>&quot;%1&quot; blev ændret.
Gem disse ændringer?</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Kan ikke skrive til databasen.</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Gem database som</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Ny database</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>låst</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassX.
Do you want to open it anyway? Alternatively the database is opened read-only.</source>
        <translation>Den database, du prøver at åbne er låst af en anden forekomst af KeePassX.
Vil du åbne den alligevel? Alternativt åbnes databasen skrivebeskyttet.</translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation>Lås database</translation>
    </message>
    <message>
        <source>Can't lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation>Kan ikke låse databasen, mens du redigerer i den.
Tryk på Afbryd for at afslutte dine ændringer eller kassere dem.</translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation>Denne database er aldrig blevet gemt.
Du kan gemme databasen eller stop låsning.</translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation>Denne database er blevet ændret.
Vil du gemme databasen før låsning?
Ellers mister du dine ændringer.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation>&quot;%1&quot; er i redigeringstilstand.
Kassér ændringer og luk alligevel?</translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation>Eksportér databasen til CSV-fil</translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation>CSV-fil</translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation>Kan ikke skrive til CSV-fil.</translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassX.
Do you want to save it anyway?</source>
        <translation>Databasen som du prøver at gemme er låst af en anden instans af KeePassX.
Vil du alligevel gemme?</translation>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation>Skift hovednøgle</translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation>Slet post?</translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation>Vil du virkelig slette posten &quot;%1&quot; permanent?</translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation>Slet poster?</translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation>Vil du virkelig slette %1 poster permanent?</translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation>Flyt poster til skraldespanden?</translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation><numerusform>Ønsker du virkelig at flytte %n post over i  papirkurven?</numerusform><numerusform>Ønsker du virkelig at flytte %n poster over i  papirkurven?</numerusform></translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation>Slet gruppe?</translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation>Ønsker du at slette gruppen &quot;%1&quot; permanent?</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>Nuværende gruppe</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Kan ikke  beregne hovednøgle</translation>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation>Post</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avanceret</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Ikon</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Auto-Indsæt</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Egenskaber</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historik</translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation>Indtastningshistorik</translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation>Tilføj post</translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation>Rediger post</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Andre kodeord leveret.</translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation>Ny attribut</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Vælg fil</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>Filen kan ikke åbnes</translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation>Gem vedhæftning</translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation>Kan ikke gemme vedhæftningen:</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>I morgen</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n uge</numerusform><numerusform>%n uger</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation><numerusform>%n måned</numerusform><numerusform>%n måneder</numerusform></translation>
    </message>
    <message>
        <source>1 year</source>
        <translation>Et år</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation>Yderligere attributter</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation>Vedhæftninger</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åben</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation>Aktivér Auto-Indsæt for denne post</translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the group</source>
        <translation>Nedarv standard Auto-Indsæt sekvens fra gruppe</translation>
    </message>
    <message>
        <source>Use custom Auto-Type sequence:</source>
        <translation>Brug brugerdefineret Auto-indsæt sekvens:</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation>Vinduestitel:</translation>
    </message>
    <message>
        <source>Use default sequence</source>
        <translation>Brug standardsekvens</translation>
    </message>
    <message>
        <source>Set custom sequence:</source>
        <translation>Definér brugervalgt sekvens:</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Gendan</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation>Slet alle</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Brugernavn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Kodeord:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Gentag:</translation>
    </message>
    <message>
        <source>Gen.</source>
        <translation>Generer</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Udløber</translation>
    </message>
    <message>
        <source>Presets</source>
        <translation>Predefinerede</translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation>Noter:</translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation>Gruppe</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Ikon</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Egenskaber</translation>
    </message>
    <message>
        <source>Add group</source>
        <translation>Tilføj gruppe</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Rediger gruppe</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Aktiver</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Deaktivér</translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation>Arv fra forældregruppe (%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Noter</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Udløber</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <source>Auto-type</source>
        <translation>Auto-indsæt</translation>
    </message>
    <message>
        <source>Use default auto-type sequence of parent group</source>
        <translation>Brug standard Auto-Indsæt sekvens fra forældregruppe</translation>
    </message>
    <message>
        <source>Set default auto-type sequence</source>
        <translation>Definér standard auto-indsæt sekvens</translation>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Use default icon</source>
        <translation>Brug standardikon</translation>
    </message>
    <message>
        <source>Use custom icon</source>
        <translation>Brug brugerbestemt ikon</translation>
    </message>
    <message>
        <source>Add custom icon</source>
        <translation>Tilføj brugerbestemt ikon</translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation>Slet brugerbestemt ikon</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Billeder</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle filer</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>Vælg Billede</translation>
    </message>
    <message>
        <source>Can&apos;t delete icon!</source>
        <translation>Kan ikke slette ikon!</translation>
    </message>
    <message numerus="yes">
        <source>Can&apos;t delete icon. Still used by %n item(s).</source>
        <translation><numerusform>Kan ikke slette ikonet. Det anvendes stadig af %n element.</numerusform><numerusform>Kan ikke slette ikonet. Det anvendes stadig af %n elementer.</numerusform></translation>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation>Oprettet:</translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation>Ændret:</translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation>Tilgået:</translation>
    </message>
    <message>
        <source>Uuid:</source>
        <translation>Uuid:</translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation>Sidst ændret</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation>Gruppe</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation>Skraldespand</translation>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation>Importér KeePass1 database</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Kan ikke åbne databasen.</translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation>Kan ikke indlæse nøglefil.</translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Ikke en KeePass database.</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>Ikke understøttet krypteringsalgoritme</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Ikke understøttet KeePass database version</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>Rod</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Kan ikke beregne hovednøgle</translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Dette er ikke en KeePass database.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>KeePass database version ikke understøttet.</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>Forkert nøgle eller databasefil er korrupt.</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Kan ikke beregne hovednøgle</translation>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; 'Import KeePass 1 database'.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation>Den valgte fil er en gammel KeePass 1 databasefil (.kdb).

Du kan importere den ved at klikke på Database &gt; &apos;Importér KeePass 1 database&apos;.
Dette er en envejs konvertering. Du vil ikke være i stand til at åbne den importerede database med den gamle KeePassX 0.4 version.</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation>Fatal fejl ved test af kryptografiske funktioner.</translation>
    </message>
    <message>
        <source>KeePassX - Error</source>
        <translation>KeePassX - Fejl</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Database</source>
        <translation>Database</translation>
    </message>
    <message>
        <source>Recent databases</source>
        <translation>Seneste databaser</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <source>Entries</source>
        <translation>Poster</translation>
    </message>
    <message>
        <source>Copy attribute to clipboard</source>
        <translation>Kopiér attribut til udklipsholder</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Grupper</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Åben database</translation>
    </message>
    <message>
        <source>Save database</source>
        <translation>Gem database</translation>
    </message>
    <message>
        <source>Close database</source>
        <translation>Luk databasen</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Ny database</translation>
    </message>
    <message>
        <source>Add new entry</source>
        <translation>Tilføj ny post</translation>
    </message>
    <message>
        <source>View/Edit entry</source>
        <translation>Vis/Rediger post</translation>
    </message>
    <message>
        <source>Delete entry</source>
        <translation>Slet post</translation>
    </message>
    <message>
        <source>Add new group</source>
        <translation>Tilføj ny gruppe</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Rediger gruppe</translation>
    </message>
    <message>
        <source>Delete group</source>
        <translation>Slet gruppe</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Gem database som</translation>
    </message>
    <message>
        <source>Change master key</source>
        <translation>Skift hovednøgle</translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation>Databaseindstillinger</translation>
    </message>
    <message>
        <source>Import KeePass 1 database</source>
        <translation>Importér KeePass 1 database</translation>
    </message>
    <message>
        <source>Clone entry</source>
        <translation>Klon post</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Find</translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation>Kopiér brugernavn til udklipsholder</translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation>Kopiér kodeord til udklipsholder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>Perform Auto-Type</source>
        <translation>Udfør Auto-indsæt</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Åben URL</translation>
    </message>
    <message>
        <source>Lock databases</source>
        <translation>Lås databaser</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Noter</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>Vis værktøjslinie</translation>
    </message>
    <message>
        <source>read-only</source>
        <translation>skrivebeskyttet</translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation>Skift vindue</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Værktøj</translation>
    </message>
    <message>
        <source>Copy username</source>
        <translation>Kopiér brugernavn</translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation>Kopiér kodeord</translation>
    </message>
    <message>
        <source>Export to CSV file</source>
        <translation>Eksportér til CSV-fil</translation>
    </message>
    <message>
        <source>Repair database</source>
        <translation>Reparer database</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 Database</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle filer</translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation>Gem repareret database</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Skrivning til database fejler.</translation>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation>Kodeord:</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Længde:</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>Tegntyper</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>Store Bogstaver</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>Små Bogstaver</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Numre</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Specialtegn</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Udeluk lool-alike tegn</translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation>Vær sikker på at dit kodeord indeholder tegn fra alle grupper</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Acceptér</translation>
    </message>
</context>
<context>
    <name>QCommandLineParser</name>
    <message>
        <source>Displays version information.</source>
        <translation>Vis versionsinformation</translation>
    </message>
    <message>
        <source>Displays this help.</source>
        <translation>Vis denne hjælp.</translation>
    </message>
    <message>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation>Ukendt valgmulighed &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Unknown options: %1.</source>
        <translation>Ukendt valgmuligheder &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Missing value after &apos;%1&apos;.</source>
        <translation>Manglende værdi efter &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Unexpected value after &apos;%1&apos;.</source>
        <translation>Uventet værdi efter &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>[options]</source>
        <translation>[Valgmuligheder]</translation>
    </message>
    <message>
        <source>Usage: %1</source>
        <translation>Brug: %1</translation>
    </message>
    <message>
        <source>Options:</source>
        <translation>Muligheder:</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>Argumenter:</translation>
    </message>
</context>
<context>
    <name>QSaveFile</name>
    <message>
        <source>Existing file %1 is not writable</source>
        <translation>Eksisterende fil %1 er ikke skrivbar</translation>
    </message>
    <message>
        <source>Writing canceled by application</source>
        <translation>Skrivning afbrudt af programmet</translation>
    </message>
    <message>
        <source>Partial write. Partition full?</source>
        <translation>Delvis gemt. Diskafsnit fyldt op?</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation>Intern zlib-fejl ved komprimering:</translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation>Fejl ved skrivning til enhed:</translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation>Fejl ved åbning fra enhed:</translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation>Fejl ved læsning af data fra underliggende enhed:</translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation>Intern zlib-fejl ved dekomprimering:</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation>Gzip-format understøttes ikke i denne version af zlib.</translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation>Intern zlib fejl:</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Find:</source>
        <translation>Find:</translation>
    </message>
    <message>
        <source>Case sensitive</source>
        <translation>Versalfølsom</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>Nuværende gruppe</translation>
    </message>
    <message>
        <source>Root group</source>
        <translation>Rodgruppe</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation>Programindstillinger</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sikkerhed</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation>Husk seneste databaser</translation>
    </message>
    <message>
        <source>Open previous databases on startup</source>
        <translation>Åben foregående databaser ved opstart</translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation>Gem automatisk ved afslutning</translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation>Gem automatisk ved ændringer</translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation>Minimér ved kopiering til udklipsholder</translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation>Brug gruppeikon ved oprettelse af post</translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation>Global Auto-Indsæt genvej</translation>
    </message>
    <message>
        <source>Use entry title to match windows for global auto-type</source>
        <translation>Brug titel på post til at matche global aito-indsæt</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Sprog</translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation>Vis et ikon i systembakken</translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation>Skjul vindue i systembakken når det er minimeret</translation>
    </message>
    <message>
        <source>Remember last key files</source>
        <translation>Husk de sidste nøglefiler</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation>Ryd udklipsholder efter</translation>
    </message>
    <message>
        <source> sec</source>
        <translation>sek</translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation>Lås databaserne efter inaktivitet i</translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation>Vis kodeord i klartekst som standard</translation>
    </message>
    <message>
        <source>Always ask before performing auto-type</source>
        <translation>Spørg altid før auto-indsæt</translation>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation>Lås database op</translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome!</source>
        <translation>Velkommen!</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>KeePassX - cross-platform password manager</source>
        <translation>KeePassX - cross-platform password manager</translation>
    </message>
    <message>
        <source>filename of the password database to open (*.kdbx)</source>
        <translation>filnavn på databasen der skal åbnes (* .kdbx)</translation>
    </message>
    <message>
        <source>path to a custom config file</source>
        <translation>sti til brugerdefineret indstillingsfil</translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation>databasens nøglefil</translation>
    </message>
</context>
</TS>